@@ -36,7 +36,9 @@ namespace Basenji.Gui
 
 Contributors:
     Francesco Marella (https://launchpad.net/~francesco-marella)
+    György Balló (https://launchpad.net/~ballogy)
     Mauro Solcia (https://launchpad.net/~maurosolcia)
+    Tobias Gruetzmacher (https://launchpad.net/~tobix)
 " };
 		
 		private static readonly string		translatorCredits	= 
@@ -76,6 +78,7 @@ French:
     Olivier Duperray (https://launchpad.net/~duperray-olivier)
     Pierre Slamich (https://launchpad.net/~pierre-slamich)
     Stephane Ricci (https://launchpad.net/~stephane-ricci)
+    Tubuntu (https://launchpad.net/~t-ubuntu)
     Y.Bélaïd (https://launchpad.net/~belaid-younsi-gmail)
 
 German:
@@ -102,6 +105,7 @@ Occitan (post 1500):
     Cédric Valmary (https://launchpad.net/~cvalmary)
 
 Polish:
+    axel (https://launchpad.net/~axel334)
     Piotr Strębski (https://launchpad.net/~strebski)
     Stanisław Chmiela (https://launchpad.net/~chmiela-st)
     Szymon Sieciński (https://launchpad.net/~szymon-siecinski)
@@ -110,9 +114,11 @@ Polish:
 Russian:
     Alexander 'FONTER' Zinin (https://launchpad.net/~spore-09)
     Alexey Ivanov (https://launchpad.net/~alexey-ivanov)
+    Claque (https://launchpad.net/~cpt-alatriste)
     Dmitri Konoplev (https://launchpad.net/~knoplef)
     Eugene Marshal (https://launchpad.net/~lowrider)
     Nikolai Romanik (https://launchpad.net/~arhey)
+    oleh (https://launchpad.net/~rolenin-c)
     Oleksiy Zaytsev (https://launchpad.net/~alexiy74)
     Papazu (https://launchpad.net/~pavel-z)
     Sciko (https://launchpad.net/~tempsciko-gmail)
@@ -121,8 +127,12 @@ Russian:
 
 Serbian:
     Kosava (https://launchpad.net/~kosava)
+    Мирослав Николић (https://launchpad.net/~lipek)
     Srdjan Hrnjak (https://launchpad.net/~srdjan-hrnjak)
 
+Slovak:
+    Izidor Matušov (https://launchpad.net/~izidor)
+
 Spanish:
     Alfredo Hernández (https://launchpad.net/~aldomann)
     Daniel Garcia Stelzner (https://launchpad.net/~dani-garcia87)
@@ -130,6 +140,7 @@ Spanish:
     Emiliano (https://launchpad.net/~emilianohfernandez)
     Feder Sáiz (https://launchpad.net/~federsaiz)
     Fitoschido (https://launchpad.net/~fitoschido)
+    Guillermo Espertino (Gez) (https://launchpad.net/~gespertino-gmail)
     Luis García (https://launchpad.net/~luismihn)
     Jonay Santana (https://launchpad.net/~jonay-santana)
     Jorge Dardón (https://launchpad.net/~jdardon)
