@@ -1,6 +1,6 @@
 // MainWindow.cs
 // 
-// Copyright (C) 2008 - 2010 Patrick Ulbrich
+// Copyright (C) 2008 - 2012 Patrick Ulbrich
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 //
 
 using System;
+using System.Collections.Generic;
 using System.Threading;
 using Gtk;
 using System.IO;
@@ -101,7 +102,76 @@ namespace Basenji.Gui
 				}
 			}			 
 		}
-
+		
+		// finds the specified item:
+		// - select owner volume
+		// - expand the treeview path to the item
+		//   and select the item
+		public void FindItem(VolumeItem item) {
+			if (item == null)
+				throw new ArgumentNullException("item");
+			
+			// get path of volume ids to item
+			Stack<long> path = new Stack<long>();
+			VolumeItem tmp = item;
+			
+			while (tmp.ItemID != 1) { // skip root item
+				path.Push(tmp.ItemID);
+				tmp = database.GetVolumeItem(tmp.VolumeID, tmp.ParentID);
+			}
+			
+			// find and select volume of specified item
+			TreeModel model = tvVolumes.Model;
+			TreeIter iter;
+			long volumeID = item.VolumeID;
+			bool hasMoreIters = true;
+			
+			model.GetIterFirst(out iter);
+			
+			while (hasMoreIters) {
+				Volume vol = tvVolumes.GetVolume(iter);
+				
+				if (vol.VolumeID == volumeID) {
+					// select owner volume
+					tvVolumes.Selection.SelectIter(iter);
+					tvVolumes.ScrollToCell(model.GetPath(iter), null, false, .0f, .0f);
+					
+					if (path.Count > 0) {
+						// find and select specified item
+						tvItems.Model.GetIterFirst(out iter);
+						FindItemRecursive(iter, path);
+					} // else : specified item is the root item so select nothing
+					break;
+				}
+				
+				hasMoreIters = model.IterNext(ref iter);
+			}
+		}
+		
+		private void FindItemRecursive(TreeIter iter, Stack<long> path) {
+			TreeModel model = tvItems.Model;
+			bool hasMoreIters = true;
+			long itemID = path.Pop();
+			
+			while (hasMoreIters) {
+				VolumeItem item = tvItems.GetItem(iter);
+				
+				if (item.ItemID == itemID) {
+					if (path.Count > 0) {
+						tvItems.ExpandRow(model.GetPath(iter), false);
+						model.IterChildren(out iter, iter);
+						FindItemRecursive(iter, path);
+					} else {
+						tvItems.Selection.SelectIter(iter);
+						tvItems.ScrollToCell(model.GetPath(iter), null, false, .0f, .0f);
+					}
+					break;
+				}
+				
+				hasMoreIters = model.IterNext(ref iter);
+			}
+		}
+		
 		private void OpenOrCreateDefaultDB(bool confirmCreation) {
 			// do not overwrite existing db				   
 			if (File.Exists(App.DefaultDB)) {
@@ -204,12 +274,14 @@ namespace Basenji.Gui
 		
 		private void EnableGui(bool enable)	{
 			actAddVolume.Sensitive		= enable;
+			actSearch.Sensitive			= enable;
+			
 			actRemoveVolume.Sensitive	= enable;
 			actEditVolume.Sensitive		= enable;
+			actEditItem.Sensitive		= enable;
 			
-			actDBProperties.Sensitive	= enable;
 			actImport.Sensitive			= enable;
-			actSearch.Sensitive			= enable;
+			actDBProperties.Sensitive	= enable;
 			
 			txtSearchString.Sensitive	= enable;
 		}
@@ -319,30 +391,14 @@ namespace Basenji.Gui
 			}
 			
 			VolumeScanner vs = new VolumeScanner(database, drive);
-			vs.NewVolumeAdded += (object o, NewVolumeAddedEventArgs args) => {
-				if (lastSuccessfulSearchCriteria != null) {
-					// the volumes treeview is filtered,
-					// so refill the treeview using the last sucessful searchcriteria.
-					// (the freshly added volume may be matched by that criteria.)
-					SearchVolumeAsync(lastSuccessfulSearchCriteria, null);
-				} else {
-					// volumes treeview isn't filtered and contains all volumes,
-					// so just append.
-					tvVolumes.AddVolume(args.Volume);
-				}
-				
-			};
+			AddNewVolumeAddedEventHandler(vs);
 		}
 		
 		private void RemoveVolume() {
 			TreeIter iter;
 			
-			if (!tvVolumes.GetSelectedIter(out iter)) {
-				MsgDialog.ShowError(this,
-				                    S._("No volume selected"),
-				                    S._("Please select a volume record to remove."));
+			if (!tvVolumes.GetSelectedIter(out iter))
 				return;
-			}
 
 			ResponseType result = MsgDialog.Show(this, 
 			                                     MessageType.Question, 
@@ -350,29 +406,15 @@ namespace Basenji.Gui
 			                                     S._("Confirmation"), 
 			                                     S._("Are you sure you really want to remove the selected volume?"));
 			
-			if (result == ResponseType.Yes) {
-				Volume volume = tvVolumes.GetVolume(iter);
-				database.RemoveVolume(volume.VolumeID);
-				
-				// remove external db data
-				string dbDataPath = PathUtil.GetDbDataPath(database);
-				string volumeDataPath = DbData.GetVolumeDataPath(dbDataPath, volume.VolumeID);
-				if (Directory.Exists(volumeDataPath))
-					Directory.Delete(volumeDataPath, true);
-				
-				tvVolumes.RemoveVolume(iter);
-			}
+			if (result == ResponseType.Yes)
+				PurgeVolume(iter);
 		}
 		
 		private void EditVolume() {
 			TreeIter iter;
 			
-			if (!tvVolumes.GetSelectedIter(out iter)) {
-				MsgDialog.ShowError(this,
-				                    S._("No volume selected"),
-				                    S._("Please select a volume to edit."));
+			if (!tvVolumes.GetSelectedIter(out iter))
 				return;
-			}
 			
 			// load volume properties
 			Volume volume = tvVolumes.GetVolume(iter);
@@ -385,12 +427,8 @@ namespace Basenji.Gui
 		private void EditItem() {
 			TreeIter iter;
 			
-			if (!tvItems.GetSelectedIter(out iter)) {
-				MsgDialog.ShowError(this,
-				                    S._("No item selected"),
-				                    S._("Please select an item to edit."));
+			if (!tvItems.GetSelectedIter(out iter))
 				return;
-			}
 			
 			// load item properties
 			VolumeItem item = tvItems.GetItem(iter);
@@ -405,6 +443,34 @@ namespace Basenji.Gui
 //			};
 		}
 		
+		private void PurgeVolume(TreeIter volumeIter) {
+			Volume volume = tvVolumes.GetVolume(volumeIter);
+			database.RemoveVolume(volume.VolumeID);
+			
+			// remove external db data
+			string dbDataPath = PathUtil.GetDbDataPath(database);
+			string volumeDataPath = DbData.GetVolumeDataPath(dbDataPath, volume.VolumeID);
+			if (Directory.Exists(volumeDataPath))
+				Directory.Delete(volumeDataPath, true);
+			
+			tvVolumes.RemoveVolume(volumeIter);
+		}
+		
+		private void AddNewVolumeAddedEventHandler(VolumeScanner vs) {
+			vs.NewVolumeAdded += (object o, NewVolumeAddedEventArgs args) => {
+				if (lastSuccessfulSearchCriteria != null) {
+					// the volumes treeview is filtered,
+					// so refill the treeview using the last sucessful searchcriteria.
+					// (the freshly added volume may be matched by that criteria.)
+					SearchVolumeAsync(lastSuccessfulSearchCriteria, null);
+				} else {
+					// volumes treeview isn't filtered and contains all volumes,
+					// so just append.
+					tvVolumes.AddVolume(args.Volume);
+				}
+			};
+		}
+		
 		private void BeginVolumeSearch() {
 			ISearchCriteria criteria = null;
 			
@@ -536,6 +602,19 @@ namespace Basenji.Gui
 			App.Settings.Save();
 		}
 		
+		private void OnActAddVolumeActivated(object sender, System.EventArgs args) {
+			AddVolume();
+		}
+		
+		private void OnActSearchActivated(object sender, System.EventArgs args) {
+			ItemSearch s = new ItemSearch(this, database);
+			s.Show();
+		}
+		
+		private void OnActShowAppMenuActivated(object sender, System.EventArgs args) {
+			appMenu.Popup(null, null, null, 1, Gtk.Global.CurrentEventTime);
+		}
+		
 		private void OnActNewDBActivated(object sender, System.EventArgs args) {
 			SelectNewDB();
 		}
@@ -579,25 +658,83 @@ namespace Basenji.Gui
 			import.Show();
 		}
 		
-		private void OnActSearchActivated(object sender, System.EventArgs args) {
-			ItemSearch s = new ItemSearch(database);
-			s.Show();
+		private void OnActPreferencesActivated(object sender, System.EventArgs args) {
+			Preferences p = new Preferences();
+			p.Show();
 		}
 		
 		private void OnActDBPropertiesActivated(object sender, System.EventArgs args) {
 			ShowDBProperties();
 		}
 		
-		private void OnActAddVolumeActivated(object sender, System.EventArgs args) {
-			AddVolume();
+		private void OnActInfoActivated(object sender, System.EventArgs args) {
+			About a = new About();
+			a.Run();
+			a.Destroy();
+		}
+		
+		private void OnActQuitActivated(object sender, System.EventArgs args) {
+			Quit();
+		}
+		
+		private void OnActEditVolumeActivated(object sender, System.EventArgs args) {
+			EditVolume();
 		}
 		
 		private void OnActRemoveVolumeActivated(object sender, System.EventArgs args) {
 			RemoveVolume();
 		}
 		
-		private void OnActEditVolumeActivated(object sender, System.EventArgs args) {
-			EditVolume();
+		private void OnActRescanVolumeActivated(object sender, System.EventArgs args) {
+			TreeIter iter;
+			if (!tvVolumes.GetSelectedIter(out iter))
+				return;
+			
+			Volume oldVolume = tvVolumes.GetVolume(iter);
+			
+			WaitFunc<PlatformIO.DriveInfo> IsVolumeConnected = delegate(out PlatformIO.DriveInfo dinf) {
+				foreach (PlatformIO.DriveInfo di in PlatformIO.DriveInfo.GetDrives()) {
+					if (di.IsReady && di.IsMounted && 
+					    	(di.DriveType.ToVolumeDriveType() == oldVolume.DriveType) && 
+					    	(di.VolumeLabel == oldVolume.Title)) {
+						dinf = di;
+						return true;
+					}
+				}
+				dinf = null;
+				return false;
+			};
+			
+			bool proceed = true;
+			PlatformIO.DriveInfo drive;
+			
+			if (!IsVolumeConnected(out drive)) {
+				string message = string.Format(S._("Please insert volume '<b>{0}</b>'."), Util.Escape(oldVolume.Title));
+				var wd = new WaitingDialog<PlatformIO.DriveInfo>(IsVolumeConnected, message);
+				wd.Title = S._("Waiting for volume");
+				if (wd.Run() == (int)ResponseType.Ok) {
+					proceed = true;
+					drive = wd.Value;
+				} else {
+					proceed = false;
+				}
+				wd.Destroy();
+			}
+			
+			if (proceed) {
+				VolumeScanner vs = new VolumeScanner(database, drive);
+				vs.VolumeEditor.Load(oldVolume);
+				// remove old volume from the volume treeview and purge all associated data
+				vs.NewVolumeAdded += (object o, NewVolumeAddedEventArgs a) => {
+					PurgeVolume(iter);
+				};
+				// add new volume to the volume treeview
+				AddNewVolumeAddedEventHandler(vs);
+			}
+		}
+		
+		private void OnActEditItemActivated(object sender, System.EventArgs args) {
+			EditItem();
 		}
 		
 		private void OnSortActionActivated(object sender, System.EventArgs args) {
@@ -625,43 +762,58 @@ namespace Basenji.Gui
 			SaveVolumeSortProperty(sp, desc); 
 		}
 		
-		private void OnActEditItemActivated(object sender, System.EventArgs args) {
-			EditItem();
-		}
-		
-		private void OnActPreferencesActivated(object sender, System.EventArgs args) {
-			Preferences p = new Preferences();
-			p.Show();
-		}
-		
-		private void OnActQuitActivated(object sender, System.EventArgs args) {
-			Quit();
-		}
-		
 		[GLib.ConnectBefore()]
 		private void OnTvVolumesButtonPressEvent(object o, ButtonPressEventArgs args) {
 			TreePath path;
 			tvVolumes.GetPathAtPos((int)args.Event.X, (int)args.Event.Y, out path);
-			//if (path == null)
-			//	return;
-				
+			
 			if ((args.Event.Button == 1) && (args.Event.Type == Gdk.EventType.TwoButtonPress)) {
 				if (path != null)
 					EditVolume();
 			} else if ((args.Event.Button == 3) && (args.Event.Type == Gdk.EventType.ButtonPress)) {
-				uint btn = args.Event.Button;
-				uint time = args.Event.Time;
-				if (path != null)
+				// re-enqueue into gtk mainloop since 
+				// the row that has been right-clicked is not selected yet 
+				// (iter is off by one in this event).
+				Application.Invoke(delegate {
+					if (path == null) {
+						// show "sort by" action only
+						actRemoveVolume.Visible = false;
+						actEditVolume.Visible = false;
+						actRescanVolume.Visible = false;
+					} else {
+						actRemoveVolume.Visible = true;
+						actEditVolume.Visible = true;
+						actRescanVolume.Visible = true;
+						
+						TreeIter iter;
+						tvVolumes.GetSelectedIter(out iter);
+						Volume volume = tvVolumes.GetVolume(iter);
+						
+						actRescanVolume.Sensitive = ((volume.DriveType == VolumeDriveType.Removable) || 
+						                             (volume.DriveType == VolumeDriveType.Harddisk) || 
+						                             (volume.DriveType == VolumeDriveType.Network) ||
+						                             ((volume.DriveType == VolumeDriveType.CDRom) && 
+						 							 (volume.GetVolumeType() != VolumeType.AudioCdVolume)));
+					}
+					
+					uint btn = args.Event.Button;
+					uint time = args.Event.Time;
 					volumeContextMenu.Popup(null, null, null, btn, time);
-				else
-					volumeSortContextMenu.Popup(null, null, null, btn, time);
+				});
 			}
 		}
 		
 		[GLib.ConnectBefore()]
 		private void OnTvVolumesKeyPressEvent(object o, Gtk.KeyPressEventArgs args) {
-			if (args.Event.Key == Gdk.Key.Return)
-				EditVolume();
+			switch (args.Event.Key)
+			{
+				case Gdk.Key.Return:
+					EditVolume();
+					break;
+				case Gdk.Key.Delete:
+					RemoveVolume();
+					break;
+			}
 		}
 		
 		private void OnTvVolumesSelectionChanged(object o, EventArgs args) {
@@ -725,41 +877,32 @@ namespace Basenji.Gui
 			windowDeleted = true;
 			Quit();
 			args.RetVal = true;
-		}		
-		
-		private void OnActInfoActivated(object sender, System.EventArgs args) {
-			About a = new About();
-			a.Run();
-			a.Destroy();
 		}
 	}
 	
 	// gui initialization
 	public partial class MainWindow : Base.WindowBase
 	{
-		// menubar
-		MenuBar menubar;
-			
-		private Gtk.Action actFile;
-		private Gtk.Action actEdit;
-		private Gtk.Action actHelp;
+		// toolbar actions
+		private Gtk.Action actAddVolume;
+		private Gtk.Action actSearch;
+		private Gtk.Action actShowAppMenu;
 		
+		// app menu actions
 		private Gtk.Action actNewDB;
 		private Gtk.Action actOpenDB;
 		private Gtk.Action actOpenDefaultDB;
-		private Gtk.Action actDBProperties;
-		private Gtk.Action actImport;
-		private Gtk.Action actSearch;
-		private Gtk.Action actQuit;
 		private Gtk.RecentAction actRecentlyUsed;
+		private Gtk.Action actImport;
+		private Gtk.Action actPreferences;
+		private Gtk.Action actDBProperties;
+		private Gtk.Action actInfo;
+		private Gtk.Action actQuit;
 		
-		private Gtk.Action actAddVolume;
+		// context menu actions
 		private Gtk.Action actRemoveVolume;
 		private Gtk.Action actEditVolume;
-		private Gtk.Action actPreferences;
-		
-		private Gtk.Action actInfo;
-		
+		private Gtk.Action actRescanVolume;
 		private Gtk.Action actEditItem;
 		
 		private Gtk.Action actVolumesSortBy;
@@ -769,9 +912,11 @@ namespace Basenji.Gui
 		// toolbar
 		private Toolbar toolbar;
 		
+		// app menu
+		private Menu appMenu;
+		
 		// context menus
 		private Menu volumeContextMenu;
-		private Menu volumeSortContextMenu;
 		private Menu itemContextMenu;
 		
 		// search entry
@@ -814,11 +959,23 @@ namespace Basenji.Gui
 			
 			// actiongroup			  
 			ActionGroup ag = new ActionGroup("default");			
+
+			//
+			// toolbar actions
+			//
+			actAddVolume = CreateAction("addvolume", S._("Add Volume"), null, Stock.Add, OnActAddVolumeActivated);
+			actAddVolume.IsImportant = true;
+			ag.Add(actAddVolume);
 			
-			// file menu
-			actFile = CreateAction("file", S._("_File"), null, null, null);
-			ag.Add(actFile, null);
+			actSearch = CreateAction("searchitems", S._("Search"), null, Stock.Find, OnActSearchActivated);
+			ag.Add(actSearch);
 			
+			actShowAppMenu = CreateAction("show_appmenu", S._("App Menu"), null, Stock.Properties, OnActShowAppMenuActivated);
+			ag.Add(actShowAppMenu);
+			
+			//
+			// app menu actions
+			//
 			actNewDB = CreateAction("newdb", AppendDots(S._("_New Database")), null, Stock.New, OnActNewDBActivated);
 			ag.Add(actNewDB, "<control>N");
 			
@@ -828,62 +985,57 @@ namespace Basenji.Gui
 			actOpenDefaultDB = CreateAction("open_default_db", S._("Open Default Database"), null, null, OnActOpenDefaultDBActivated);
 			ag.Add(actOpenDefaultDB);
 			
-			actDBProperties = CreateAction("dbproperties", S._("_Database Properties"), null, Stock.Properties, OnActDBPropertiesActivated);
-			ag.Add(actDBProperties, "<control>D");
-			
-			actImport = CreateAction("import", AppendDots(S._("_Import")), null, null, OnActImportActivated);
-			ag.Add(actImport, "<control>I");
-			
-			actQuit = CreateAction("quit", S._("_Quit"), null, Stock.Quit, OnActQuitActivated);
-			ag.Add(actQuit, "<control>Q");			  
-			
 			RecentFilter filter = new RecentFilter();
-			filter.AddApplication(App.Name);
+			filter.AddPattern("*.vdb");
 			
 			actRecentlyUsed = new RecentAction("recent_files", S._("Recent Databases"), null, null, recentManager);
 			actRecentlyUsed.ShowNumbers = true;
 			actRecentlyUsed.SortType = RecentSortType.Mru;
 			actRecentlyUsed.AddFilter(filter);
 			actRecentlyUsed.ItemActivated += OnActRecentlyUsedActivated;
-			ag.Add(actRecentlyUsed, null);
+			ag.Add(actRecentlyUsed);
 			
-			// edit menu
-			actEdit = CreateAction("edit", S._("_Edit"), null, null, null);
-			ag.Add(actEdit, null);
+			actImport = CreateAction("import", AppendDots(S._("_Import")), null, null, OnActImportActivated);
+			ag.Add(actImport, "<control>I");
 			
 			actPreferences = CreateAction("preferences", S._("_Preferences"), null, Stock.Preferences, OnActPreferencesActivated);
-			ag.Add(actPreferences, "<control>P");			 
+			ag.Add(actPreferences, "<control>P");			
 			
-			// help menu
-			actHelp = CreateAction("help", S._("_Help"), null, null, null);
-			ag.Add(actHelp, null);
+			actDBProperties = CreateAction("dbproperties", S._("_Database Properties"), null, Stock.Properties, OnActDBPropertiesActivated);
+			ag.Add(actDBProperties, "<control>D");
 			
-			actInfo = CreateAction("info", S._("_Info"), null, Stock.About, OnActInfoActivated);
+			actInfo = CreateAction("info", S._("Info"), null, Stock.About, OnActInfoActivated);
 			ag.Add(actInfo);	
 			
-			// shared actions (used in toolbar buttons / menu items / context menus)
-			actAddVolume = CreateAction("addvolume", S._("_Add Volume"), null, Stock.Add, OnActAddVolumeActivated);
-			actAddVolume.IsImportant = true;
-			ag.Add(actAddVolume, "<control>A");
+			actQuit = CreateAction("quit", S._("_Quit"), null, Stock.Quit, OnActQuitActivated);
+			ag.Add(actQuit, "<control>Q");			  
+			
+			//
+			// volume context menu actions
+			//
+			actEditVolume = CreateAction("editvolume", S._("_Edit Volume"), null, Stock.Edit, OnActEditVolumeActivated);
+			ag.Add(actEditVolume, "<control>E");
 			
 			actRemoveVolume = CreateAction("removevolume", S._("_Remove Volume"), null, Stock.Remove, OnActRemoveVolumeActivated);
 			ag.Add(actRemoveVolume, "<control>R");
 			
-			actEditVolume = CreateAction("editvolume", S._("_Edit Volume"), null, Stock.Edit, OnActEditVolumeActivated);
-			ag.Add(actEditVolume, "<control>E");
+			actRescanVolume = CreateAction("rescanvolume", S._("Rescan Volume"), null, Stock.Refresh, OnActRescanVolumeActivated);
+			ag.Add(actRescanVolume, "<control>S");
 			
-			actSearch = CreateAction("searchitems", S._("_Search"), null, Stock.Find, OnActSearchActivated);
-			ag.Add(actSearch, "<control>S");
-			
-			// context menus
+			//
+			// item context menus
+			//
 			actEditItem = CreateAction("edititem", S._("Edit Item"), null, Stock.Edit, OnActEditItemActivated);
-			ag.Add(actEditItem, null);
+			ag.Add(actEditItem);
 			
+			//
+			// sort context menu actions
+			//
 			actVolumesSortBy = CreateAction("volumes_sortby", S._("Sort by"), null, null, null);
-			ag.Add(actVolumesSortBy, null);
+			ag.Add(actVolumesSortBy);
 			
 			actVolumesSortDescending = CreateToggleAction("volumes_sortdescending", S._("Descending"), null, null, OnSortActionActivated);
-			ag.Add(actVolumesSortDescending, null);
+			ag.Add(actVolumesSortDescending);
 			
 			RadioAction tmp = CreateRadioAction("volumes_sortby_archiveno", S._("Archive No."), null, null, (int)Widgets.VolumeSortProperty.ArchiveNo, null, OnSortActionActivated);
 			volumeSortActions = new Gtk.RadioAction[] {
@@ -907,74 +1059,60 @@ namespace Basenji.Gui
 			}
 			actVolumesSortDescending.Active = desc;
 			
+			//
 			// ui manager
+			//
 			UIManager manager = new UIManager();
 			manager.InsertActionGroup(ag, 0);
 			this.AddAccelGroup(manager.AccelGroup);
 			
-			string sortMenu = @"
-			<menu action=""volumes_sortby"">
-				<menuitem action=""volumes_sortby_archiveno""/>
-				<menuitem action=""volumes_sortby_added""/>
-				<menuitem action=""volumes_sortby_title""/>
-				<menuitem action=""volumes_sortby_category""/>
-				<menuitem action=""volumes_sortby_drivetype""/>
-				<separator/>
-				<menuitem action=""volumes_sortdescending""/>
-			</menu>";
-			
-			string ui = string.Format(@"
+			string ui = @"
 			<ui>
-				<menubar name=""menubar"">
-					<menu action=""file"">
-						<menuitem action=""newdb""/>
-						<menuitem action=""opendb""/>
-						<menuitem action=""open_default_db""/>
-						<menuitem action=""recent_files""/>
-						<separator/>
-						<menuitem action=""dbproperties""/>
-						<menuitem action=""import""/>
-						<menuitem action=""searchitems""/>
-						<separator/>
-						<menuitem action=""quit""/>
-					</menu>
-					<menu action=""edit"">
-						<menuitem action=""addvolume""/>
-						<menuitem action=""removevolume""/>
-						<menuitem action=""editvolume""/>
-						<separator/>
-						<menuitem action=""preferences""/>
-					</menu>
-					<menu action=""help"">
-						<menuitem action=""info""/>
-					</menu>
-				</menubar>
 				<toolbar name=""toolbar"">
 					<toolitem action=""addvolume""/>
-					<separator/>
 					<toolitem action=""searchitems""/>
+					<separator expand=""true""/>
+					<toolitem action=""show_appmenu""/>
 				</toolbar>
+				<popup name=""appmenu"">
+					<menuitem action=""newdb""/>
+					<menuitem action=""opendb""/>
+					<menuitem action=""open_default_db""/>
+					<menuitem action=""recent_files""/>
+					<menuitem action=""import""/>
+					<separator/>
+					<menuitem action=""preferences""/>
+					<menuitem action=""dbproperties""/>
+					<separator/>
+					<menuitem action=""info""/>
+					<menuitem action=""quit""/>
+				</popup>
 				<popup name=""volume_contextmenu"">
 					<menuitem action=""editvolume""/>
 					<menuitem action=""removevolume""/>
+					<menuitem action=""rescanvolume""/>
 					<separator/>
-					{0}
-				</popup>
-				<popup name=""volume_sort_contextmenu"">
-					{0}
+					<menu action=""volumes_sortby"">
+						<menuitem action=""volumes_sortby_archiveno""/>
+						<menuitem action=""volumes_sortby_added""/>
+						<menuitem action=""volumes_sortby_title""/>
+						<menuitem action=""volumes_sortby_category""/>
+						<menuitem action=""volumes_sortby_drivetype""/>
+						<separator/>
+						<menuitem action=""volumes_sortdescending""/>
+					</menu>
 				</popup>
 				<popup name=""item_contextmenu"">
 					<menuitem action=""edititem""/>
 				</popup>
 			</ui>
-			", sortMenu);
+			";
 			
 			manager.AddUiFromString(ui);
 			
-			menubar					= (MenuBar)manager.GetWidget("/menubar");
+			appMenu					= (Menu)manager.GetWidget("/appmenu");
 			toolbar					= (Toolbar)manager.GetWidget("/toolbar");
 			volumeContextMenu		= (Menu)manager.GetWidget("/volume_contextmenu");
-			volumeSortContextMenu	= (Menu)manager.GetWidget("/volume_sort_contextmenu");
 			itemContextMenu			= (Menu)manager.GetWidget("/item_contextmenu");
 			
 			// gtk will use SmallToolbar on windows by default 
@@ -983,7 +1121,6 @@ namespace Basenji.Gui
 			toolbar.ToolbarStyle	= Gtk.ToolbarStyle.BothHoriz;
 			toolbar.ShowArrow		= false;
 			
-			vbOuter.PackStart(menubar, false, false, 0);
 			vbOuter.PackStart(toolbar, false, false, 0);
 			
 			// hpaned			 
@@ -1014,7 +1151,7 @@ namespace Basenji.Gui
 				new Widgets.SearchEntryPreset("size", "size", "> 700mb")
 			});
 			
-			vbLeft.PackStart(txtSearchString, false, false, 0);
+			vbLeft.PackStart(txtSearchString.GetFallbackWrapper(), false, false, 0);
 			
 			hpaned.Pack1(vbLeft, false, false);
 			
