@@ -45,17 +45,17 @@ namespace Basenji.Gui
 		private MetadataProvider[]		mdps;
 		private StringBuilder			scannerLog;
 		private StatusUpdateTimer		timer;
+		private volatile bool			scanCompleted;
+		private Volume					newVolume;
 
 		public VolumeScanner(VolumeDatabase db, DriveInfo drive) {
+			this.scanCompleted = false;
 			this.database = db;
+			this.newVolume = null;
 			
 			infoIcon	= RenderIcon(Icons.Icon.Stock_DialogInfo,	   ICON_SIZE);
 			warningIcon = RenderIcon(Icons.Icon.Stock_DialogWarning,   ICON_SIZE);
-			errorIcon	= RenderIcon(Icons.Icon.Stock_DialogError,	   ICON_SIZE);			  
-			
-			////this.Destroyed += Object_Destroyed;
-			//volInfo.Sensitive = false; // will be enabled when scanning has been finished
-			//InitTreeView();
+			errorIcon	= RenderIcon(Icons.Icon.Stock_DialogError,	   ICON_SIZE);
 			
 			mdps = null;
 			
@@ -97,22 +97,18 @@ namespace Basenji.Gui
 			database.BeginWriteAccess	+= database_BeginWriteAccess;
 			database.EndWriteAccess		+= database_EndWriteAccess;
 			
-			BuildGui();					// must be called _after_ scanner instanciation (requires scanner.VolumeInfo.GetVolumeType())
-			volEditor.Sensitive = false;	// will be enabled when scanning has been finished
+			// must be called _after_ scanner instanciation 
+			// (requires scanner.VolumeInfo.GetVolumeType())
+			BuildGui();
 			InitTreeView();
 			
 			scannerLog = new StringBuilder();
 			timer = new StatusUpdateTimer(this);
 			
 			try {
-				//AddIdleHandler(); // NOTE: make sure the idle handler will be removed properly later, or it will consume a lot of cpu power, even if this window has been closed! (check taskman)
-				
 				/* NOTE: make sure the timer will be removed properly later, 
 				 * or it keeps running, even if this window has been closed. */
 				timer.Install();
-
-				//Log(new LogItem(LogIcon.Info, string.Format("Scanning of drive '{0}' started. [buffersize: {1}, hashing: {2}]", driveName, bufferSize, enableHashing ? "on" : "off")));
-				////m_scanner.BeginScanning(driveName, false);
 				
 				string tmp;
 				// e.g. GIO network 'drives' do not have a devicefile
@@ -139,9 +135,19 @@ namespace Basenji.Gui
 						throw new NotImplementedException(string.Format("Missing options output for scannertyp {0}", scanner.GetType()));
 				}
 				
-				scanner.RunAsync(); // starts scanning on a new thread and returns
+				if (scanner.VolumeInfo.GetVolumeType() == VolumeType.FileSystemVolume) {
+					// copy already known volume data into the editor
+					volEditor.ArchiveNo = scanner.VolumeInfo.ArchiveNo;
+					volEditor.Title = scanner.VolumeInfo.Title;
+				} else {
+					// other volumetypes have no useful data yet (e.g. AudioCD data may be queried from musicbrainz.org), 
+					// so disable the editor and re-enable it and fill in the data when scanning has been completed.
+					volEditor.Sensitive = false;
+				}
+				
+				// start scanning on a new thread and return immediately
+				scanner.RunAsync();
 			} catch {
-				//RemoveIdleHandler();
 				timer.Remove();
 				throw;
 			}
@@ -167,6 +173,10 @@ namespace Basenji.Gui
 			tvLog.Model = logStore;
 		}
 		
+		public VolumeEditor VolumeEditor {
+			get { return volEditor; }
+		}
+		
 		private void UpdateLog(LogIcon icon, string message) {
 			Pixbuf pb;
 			string messageType;
@@ -221,10 +231,14 @@ namespace Basenji.Gui
 		
 		private bool SaveAndClose() {
 			try {
-				if (scanner.ScanSucceeded) {
-					volEditor.Save(); // may throw ValidationException
-					SaveLog(volEditor.Volume.VolumeID);
-					OnNewVolumeAdded(volEditor.Volume);				 
+				if (scanner.ScanSucceeded) {				
+					// SaveTo() may throw a ValidationException.
+					// Note: The volumeditor has either been filled on scanner start manually
+					// (no volume loaded) or an existing volume has been loaded into it
+					// (via the public VolumeEditor property or via volEditor.Load() on scan completion).
+					volEditor.SaveTo(newVolume);
+					SaveLog(newVolume.VolumeID);
+					OnNewVolumeAdded(newVolume);
 				}
 
 				this.Destroy();
@@ -245,6 +259,17 @@ namespace Basenji.Gui
 			return true;
 		}
 		
+		private void AbortScan() {
+			if (!scanCompleted && btnAbort.Sensitive) {
+				UpdateLog(LogIcon.Info, S._("Stopping Scanner and performing rollback..."));
+				
+				scanner.CancelAsync();
+				/* disable button, 
+				 * it will be enabled and converted to a closebutton when the ScanCompleted event is triggered */
+				btnAbort.Sensitive = false;
+			}
+		}
+		
 		private static string BoolToStr(bool val) {
 			return val ? S._("yes") : S._("no");
 		}
@@ -268,7 +293,7 @@ namespace Basenji.Gui
 		}
 		
 		private void OnDeleteEvent(object o, Gtk.DeleteEventArgs args) {
-			if (scanner.IsBusy) {		 
+			if (!scanCompleted) {		 
 				MsgDialog.ShowError(this, S._("Scan in progress"), S._("You must stop scanning before closing this window."));
 				args.RetVal = true;
 			} else {
@@ -276,19 +301,22 @@ namespace Basenji.Gui
 				args.RetVal = cancel;
 			}
 		}
+		
+		[GLib.ConnectBefore()]
+		private void OnWindowKeyPressEvent(object o, Gtk.KeyPressEventArgs args) {
+			if (args.Event.Key == Gdk.Key.Escape) {
+				if (!scanCompleted)
+					AbortScan();
+				else
+					SaveAndClose();
+			}
+		}
 
 		private void OnBtnAbortClicked(object sender, System.EventArgs args) {
-			if (btnAbort.Label == Stock.Cancel) {
-				UpdateLog(LogIcon.Info, S._("Stopping Scanner and performing rollback..."));
-				if (scanner.IsBusy) {
-					scanner.CancelAsync();
-					/* disable button, 
-					 * it will be enabled and converted to a closebutton when the ScanCompleted event is triggered */
-					btnAbort.Sensitive = false;
-				}
-			} else {
-				SaveAndClose();				   
-			}
+			if (!scanCompleted)
+				AbortScan();
+			else
+				SaveAndClose();
 		}
 		#endregion
 		
@@ -328,37 +356,27 @@ namespace Basenji.Gui
 
 		private void scanner_ScanCompleted(object sender, ScanCompletedEventArgs e) {
 			Application.Invoke(delegate {
-				//switch (e.Result)
-				//{
-				//	  case ScanningResult.Success:
-				//		  UpdateLog(new LogItem(LogIcon.Info, "Scanning completed successfully."));
-				//		  m_ownerWindow.RefreshMediaList();
-				//		  break;
-
-				//	  case ScanningResult.Cancelled:
-				//		  UpdateLog(new LogItem(LogIcon.Error, "Scanning aborted."));
-				//		  break;
-
-				//	  case ScanningResult.FatalError:
-				//		  UpdateLog(new LogItem(LogIcon.Error, "Scanning failed. Reason: an unhandled exception occured (" + e.FatalError.Message + ")."));
-				//		  break;
-				//}
-
 				if (e.Error != null) {
 					UpdateLog(LogIcon.Error, string.Format(S._("Scanning failed. Reason: an unhandled exception occured ({0})."), e.Error.Message));
 				} else if (e.Cancelled) {
 					UpdateLog(LogIcon.Error, S._("Scanning aborted."));
 				} else {
 					UpdateLog(LogIcon.Info, S._("Scanning completed successfully."));
-					volEditor.Load(e.Volume);					   
-					volEditor.Sensitive = true;
-					//mainWindow.RefreshVolumeList(); // TODO : slow on dbs containing many volumes?
+					newVolume = e.Volume;
+
+					// the volume editor may have been disabled in the ctor 
+					// for some volume types (e.g. AudioCD volumes)
+					if (!volEditor.Sensitive) {
+						volEditor.Load(newVolume);
+						volEditor.Sensitive = true;
+					}
 				}
 
-				if (!btnAbort.Sensitive) /* possibly disabled in OnBtnAbortClicked() */
+				if (!btnAbort.Sensitive) /* possibly disabled in AbortScan() */
 					btnAbort.Sensitive = true;
 
 				btnAbort.Label = Stock.Close;
+				scanCompleted = true;
 			});
 
 			/* remove timeout handler (installed in ctor) */
@@ -373,7 +391,8 @@ namespace Basenji.Gui
 		 */
 		private class StatusUpdateTimer
 		{
-			/* GUI update frequency: (1000 / TIMEOUT_INTERVAL) Hz */
+			/* Assuming a display refresh rate (frequency) of at least 70 Hz,
+			 * the GUI update resolution shouldn't be smaller than (1000ms / 70Hz) = ~14ms */
 			private const uint TIMEOUT_INTERVAL = 20;
 
 			private VolumeScanner	vscanner;
@@ -403,7 +422,7 @@ namespace Basenji.Gui
 					bool ledOffReq = ledOffRequest;
 					
 					/* 
-					 * update counter labels 
+					 * update counter labels (expected to take less than 1ms)
 					 */
 					if (vscanner.scanner != null)
 						vscanner.volEditor.UpdateInfo(vscanner.scanner.VolumeInfo);
@@ -536,6 +555,7 @@ namespace Basenji.Gui
 			this.Add(vbOuter);
 			
 			// event handlers
+			this.KeyPressEvent += OnWindowKeyPressEvent;
 			this.DeleteEvent	+= OnDeleteEvent;
 			this.Destroyed		+= OnObjectDestroyed;
 			
