@@ -1,6 +1,6 @@
 // ItemInfo.cs
 // 
-// Copyright (C) 2008 - 2011 Patrick Ulbrich
+// Copyright (C) 2008 - 2012 Patrick Ulbrich
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -181,7 +181,8 @@ namespace Basenji.Gui.Widgets
 				GetCommonItemProperties(item, out tmp, out nameProperty);
 				
 				tmp.Add(new ItemProperty(S._("Location"), item.Location, 202));
-				tmp.Add(new ItemProperty(S._("Last write time"), item.LastWriteTime.ToString(), 205));
+				if (item.LastWriteTime.Ticks > 0L)
+					tmp.Add(new ItemProperty(S._("Last write time"), item.LastWriteTime.ToString(), 205));
 				
 				if (item.IsSymLink) {
 					FileSystemVolumeItem targetItem = item.GetSymLinkTargetItem();
@@ -329,15 +330,18 @@ namespace Basenji.Gui.Widgets
 					if (metadata.TryGetValue(MetadataType.FILENAME, out val)) {
 						// count files in archives 
 						// (filenames were joined by MetadataStore.ToDictionary())
-						string[] filenames = val.Split(KEYWORD_SEPARATORS, StringSplitOptions.None);
-						int filecount = 0;
+						int filecount = 0;						
+						int lastIndex = -1;
 						
-						foreach (string fn in filenames) {
+						while ((lastIndex = val.IndexOf(';', lastIndex + 1)) != -1)	{
 							// only count files, skip directory names
-							if ((fn[fn.Length - 1] != '/') && (fn[fn.Length - 1] != '\\'))
-								filecount++;
+							if ((val[lastIndex - 1] != '/') && (val[lastIndex - 1] != '\\'))
+									filecount++;
 						}
 						
+						if ((val[val.Length - 1] != '/') && (val[val.Length - 1] != '\\'))
+								filecount++;
+
 						if (filecount > 0)
 							tmp.Add(new ItemProperty(S._("File count"), filecount.ToString(), 117));
 					}
