@@ -1,6 +1,6 @@
 // BasenjiImport.cs
 // 
-// Copyright (C) 2010 Patrick Ulbrich
+// Copyright (C) 2010, 2012 Patrick Ulbrich
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@ using System;
 
 namespace VolumeDB.Import
 {
+/*
+	[Import("Basenji", "vdb")]
 	public sealed class BasenjiImport : AbstractImport
 	{
 		public BasenjiImport(string sourceDbPath,
@@ -35,4 +37,5 @@ namespace VolumeDB.Import
 			throw new NotImplementedException();
 		}
 	}
+*/	
 }
